using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class SoundManager : MonoBehaviour
{
    // Start is called before the first frame update
    public static SoundManager instance;
    public AudioSource music;
    public float defaultBgVolume;

    private void Awake()
    {
        instance = this;
    }
    public void PlayBGMusic()
    {
        music.volume =PlayerPrefs.GetInt("Music",1)==1? defaultBgVolume:0; //Set Volume to zero if Music if Off
        
    }
    public void StopBGMusic()
    {
        music.volume = PlayerPrefs.GetInt("Music", 1) == 1 ? defaultBgVolume : 0; //Set Volume to zero if Music if Off
    }


    public List<AudioSource> listOfAudioSource = new List<AudioSource>();
    [SerializeField] public List<SoundData> soundData = new List<SoundData>();
    public void PlaySound(SoundType soundType)
    {
        if (PlayerPrefs.GetInt("Sound", 1) == 0)
        {
            //Dont Play the Sound if Sound is Off
            return;
        }
        AudioSource audioSource = GetAudioSourceToPlay();
        if (audioSource)
        {
            SoundData soundDataToPlay = GetSoundDataForClip(soundType);
            if (soundDataToPlay!=null)
            {
                audioSource.volume = soundDataToPlay.volume;
                audioSource.clip = soundDataToPlay.clipToPlay;
                audioSource.Play();
            }
        }
        //What we need to play a sound



    }
    public AudioSource GetAudioSourceToPlay()
    {
        foreach(AudioSource audioSource in listOfAudioSource)
        {
            if (!audioSource.isPlaying)
            {
                return audioSource;
            }
        }
        return null;
    }
    public SoundData GetSoundDataForClip(SoundType soundType)
    {
        for(int i = 0; i < soundData.Count; i++)
        {
            if(soundData[i].soundType== soundType)
            {
                return soundData[i];
            }
        }
        return null;
    }
    public static void PlayClip(SoundType soundType)
    {
        if (instance)
        {
            instance.PlaySound(soundType);
        }
    }
    public static void PlayMusic()
    {
        if (SoundManager.instance)
        {
            SoundManager.instance.PlayBGMusic();
        }
    }
    public static void StopMusic()
    {
        if (SoundManager.instance)
        {
            SoundManager.instance.StopBGMusic();
        }
    }
}
[System.Serializable]
public class SoundData
{
    public SoundType soundType;
    public AudioClip clipToPlay;
    public float volume;
}
public enum SoundType
{
    click,pageIn,pageOut
}
